kustomize

package
v1.8.9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 17, 2026 License: Apache-2.0 Imports: 23 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var KustomizationNames = []string{"kustomization.yaml", "kustomization.yml", "Kustomization"}

Functions

func IsKustomization added in v0.12.0

func IsKustomization(path string) bool

IsKustomization checks if the given file name matches any known kustomization file names.

func Version added in v1.3.0

func Version() (string, error)

Types

type BuildOpts added in v1.8.8

type BuildOpts struct {
	KubeVersion string
	APIVersions []string
}

type Image added in v0.12.1

type Image = string

Image represents a Docker image in the format NAME[:TAG].

type Kustomize

type Kustomize interface {
	// Build returns a list of unstructured objects from a `kustomize build` command and extract supported parameters
	Build(opts *v1alpha1.ApplicationSourceKustomize, kustomizeOptions *v1alpha1.KustomizeOptions, envVars *v1alpha1.Env, buildOpts *BuildOpts) ([]*unstructured.Unstructured, []Image, []string, error)
}

Kustomize provides wrapper functionality around the `kustomize` command.

func NewKustomizeApp

func NewKustomizeApp(repoRoot string, path string, creds git.Creds, fromRepo string, binaryPath string, proxy string, noProxy string) Kustomize

NewKustomizeApp create a new wrapper to run commands on the `kustomize` command-line tool.

Jump to